<?php
/**
 * @category     Addons
 * @package      page module: accordion
 * @copyright    Uwe Jacobsen <webdesign@jacobi22.com>, Nibz, hgs, dbs
 * @author       Uwe Jacobsen <webdesign@jacobi22.com>, Nibz, hgs, dbs
 * @license      http://www.gnu.org/licenses/gpl.html   GPL License
 * @version      2.7.2
 * @lastmodified $Date: 2023/11/28
 * @since        File available since 2023/05/15
 * @description  addon accordion
 *
*/


namespace addon\accordion\Lib;

use bin\{WbAdaptor, SecureTokens};
use bin\helpers\{PreCheck,StopWatch};

use Twig\Loader\FilesystemLoader;
use Twig\Environment;
use Twig\TwigFilter;

class Accordion
{

    /** @var object instance of the application object */
        protected $_oApp;
    /** @var object instance of the database object */
        protected $_oDb ;
    /** @var object instance holds several values from the application global scope */
        protected $_oReg;
    /** @var object instance holds all of the translations */
        protected $_oTrans;


    // -----------------------------------------------------------------------------
    /** prevent class from public instancing and get an object to hold extensions */
    public function __construct()
    {
        // import global vars and objects
        $this->_oReg   = WbAdaptor::getInstance();
        $this->_oDb    = $this->_oReg->getDatabase();
        $this->_oTrans = $this->_oReg->getTranslate();
        $this->_oApp   = $this->_oReg->getApplication();
    }


    public function getItemSortMode($iSectionId) {
        return $this->_readItemSortMode($iSectionId);
    }
    public function CountItemEntries($iSectionId) {
        return $this->_readItemEntries($iSectionId);
    }
    public function getAllItemsArray($iSectionId,$iItemOrder) {
        return $this->_readAllItemsArray($iSectionId,$iItemOrder);
    }
    public function getAllFEItemsArray($iSectionId,$iItemOrder) {
        return $this->_readAllFEItemsArray($iSectionId,$iItemOrder);
    }
    public function getTemplateDetailArray($iSectionId, $iTemplateId) {
        return $this->_readTemplateDetailArray($iSectionId, $iTemplateId);
    }
    public function getAllTemplatesArray($iSectionId) {
        return $this->_readAllTemplatesArray($iSectionId);
    }

    public function getFeTemplateID($iSectionId) {
        return $this->_readFeTemplateID($iSectionId);
    }
    public function getFrontendTemplate($iSectionId, $iTemplateId) {
        return $this->_readFrontendTemplate($iSectionId, $iTemplateId);
    }
    public function getItemDetails($iSectionId, $iQuestId) {
        return $this->_readItemDetails($iSectionId, $iQuestId);
    }
    public function getItemGroups($iSectionId, $iImageId) {
        return $this->_readItemGroups($iSectionId, $iImageId);
    }

        ###############################################################################
        // read settings for this section (getAccordionSettings)
        ###############################################################################
            /** read default setting for this section */
                static public function getAccordionSettings($iSectionId){
                    global $aDefaults, $oAddonReg, $section_id, $page_id;
                    $oDb = \database::getInstance();
                        $aAccordionSettings  = [];
                        $sql  = 'SELECT `s_name`, `s_value` FROM `'.TABLE_PREFIX.'mod_accordion_settings` '
                            .   'WHERE `section_id` = '.(int)$iSectionId.' ';
                        if ($query = $oDb->query($sql)){
                            while ($row = $query->fetchAssoc()) {
                                $aAccordionSettings[$row['s_name']] = $row['s_value'];
                            }
                        }

                        // insert default_settings if no settings for this section avaiable
                        if (sizeof($aAccordionSettings) == 0){
//                            echo "<br>Size ist Null<br>";
                            $aFieldsList = array(
                                'section_id' => $section_id,
                                'page_id'    => $page_id,
                            );
//                            print_r($aDefaults);
                            /* add default setting if not set for this section */
                            if (\is_array($aDefaults)) {
                                $aTmp = \array_diff_key($aDefaults, $aAccordionSettings);
//                                print_r($aTmp);
                                if ($aTmp){
                                    UpdateKeyValue('mod_accordion_settings', $aDefaults, '', $aFieldsList);
                                }
                            }
                        }                        
//                        echo "<pre>";
//                        print_r($aAccordionSettings);
//                        echo "</pre>";    
                return $aAccordionSettings;
                }
        // end of static public function ('getAccordionSettings')


        ################################################################################
        // count Links for this section (CountEntrys)
        ###############################################################################
                static public function CountEntrys($iSectionId){
                    $oDb = \database::getInstance();
                    $sql= 'SELECT COUNT(*) FROM `'.TABLE_PREFIX.'mod_accordion_questions` '
                        . 'WHERE `section_id` = '.$iSectionId.' ';
                    $iCountEntrys = $oDb->get_one($sql);
                    return (@$oDb->get_error()?:$iCountEntrys);
                }
         // end of function_exists('CountEntrys') 
         // 
        ################################################################################
        // count Links for this section (CountInactiveEntrys)
        ###############################################################################
                static public function CountInactiveEntrys($iSectionId){
                    $oDb = \database::getInstance();
                    $sql= 'SELECT COUNT(*) FROM `'.TABLE_PREFIX.'mod_accordion_questions` '
                        . 'WHERE `section_id` = '.$iSectionId.' '
                        . 'AND `active` = 0';
                    $iCountInactiveEntrys = $oDb->get_one($sql);
                    return (@$oDb->get_error()?:$iCountInactiveEntrys);
                }
         // end of function_exists('CountInactiveEntrys')         
        ###############################################################################
        // get sort order for Items in this section (_readItemSortMode)
        ###############################################################################
                protected function  _readItemSortMode($iSectionId){
                    $sql= 'SELECT `s_value` FROM `'.$this->_oDb->TablePrefix.'mod_accordion_settings` '
                        . 'WHERE `section_id` = '.$iSectionId.' '
                        . 'AND `s_name` = \'ordering\' '    ;
//                    echo $sql;
                    $iItemSortMode = $this->_oDb->get_one($sql);
                    return (@$this->_oDb->get_error()?:$iItemSortMode);
                }
         // end of function_exists('_readItemSortMode')

         
        ##################################################################################
        // backend overview - complete List of all Entries (_readAllItemsArray)
        ###############################################################################
                protected function _readAllItemsArray($iSectionId,$iItemOrder){ 
                    global $admin;
                    $aResult = [];
                    $aSubItem = $aCurrItem = null;
                    if($iItemOrder == 1){ 
                        $sSortOrder = '`pos` ASC';
                    }elseif($iItemOrder == 2){ 
                        $sSortOrder = '`pos` DESC';
                    }elseif($iItemOrder == 3){ 
                        $sSortOrder = '`question` ASC';
                    }elseif($iItemOrder == 4){ 
                        $sSortOrder = '`question` DESC';
                    }elseif($iItemOrder == 5){ 
                        $sSortOrder = '`modified_when` ASC';
                    }elseif($iItemOrder == 6){ 
                        $sSortOrder = '`modified_when` DESC';
                    }else{ 
                        $sSortOrder = '`pos` ASC';
                    }
                    
                    $sql = 'SELECT * FROM `'.$this->_oDb->TablePrefix.'mod_accordion_questions` '
                                        .  'WHERE `section_id` = '.(int)$iSectionId.' '
                                        .  'ORDER by '.$sSortOrder.' ';
//                    echo "<br>Haupt:".$sql;
                    if (($oItems = $this->_oDb->query($sql))) {
                        $iLastItemId = 0;
                        while ($aItems = $oItems->fetchAssoc()) {
                                                                
                                // now create a new array with item datas
                                $aCurrItem = array();
                                $aCurrItem['section_id']          = $aItems['section_id'];
                                $aCurrItem['page_id']             = $aItems['page_id'];
                                $aCurrItem['question_id']         = $aItems['question_id'];
                                $aCurrItem['image_section']       = $aItems['section_id'];
                                $aCurrItem['question_idkey']      = $admin->getIDKEY($aItems['question_id']);
                                $aCurrItem['active']              = $aItems['active'];
                                $aCurrItem['pos']                 = $aItems['pos'];
                                $aCurrItem['question']            = $aItems['question'];
                                $aCurrItem['answer']              = $aItems['answer'];
                                $aCurrItem['status_on_pageload']  = $aItems['status_on_pageload'];
                                $aCurrItem['modified_when']       = $aItems['modified_when'];
                                $aCurrItem['modified_by']         = $aItems['modified_by'];
                                $aResult[] = $aCurrItem;;
                            }
                        }
                        
//                    echo "<pre>";
//                    print_r($aResult);
//                    echo "</pre>";

                // return the complete result structure
                    return $aResult;    
                    }
                    

                
        // end of function_exists('_readAllItemsArray')
         
        ##################################################################################
        // backend overview - complete List of all Entries (_readItemDetails)
        ###############################################################################
                protected function _readItemDetails($iSectionId,$iQuestId){ 
                    global $admin, $sAddonName,$sAddonThemeUrl;
                    $aResult = [];
                    
                    $sql = 'SELECT * FROM `'.$this->_oDb->TablePrefix.'mod_accordion_questions` '
                                        .  'WHERE `section_id` = '.(int)$iSectionId.' '
                                        .  'AND `question_id` = '.(int)$iQuestId.' ';
//                    echo "<br>Haupt:".$sql;
                    if (($oItems = $this->_oDb->query($sql))) {
                        while ($aItems = $oItems->fetchAssoc()) {
                            
                            $sAnswer = OutputFilterApi('ReplaceSysvar', $aItems['answer']);
                            $sAnswer = \htmlspecialchars($sAnswer);
                            $aResult['section_id']          = $aItems['section_id'];
                            $aResult['page_id']             = $aItems['page_id'];
                            $aResult['question_id']         = $aItems['question_id'];
                            $aResult['quest_section']       = $aItems['section_id'];
                            $aResult['question_idkey']      = $admin->getIDKEY($aItems['question_id']);
                            $aResult['active']              = $aItems['active'];
                            $aResult['pos']                 = $aItems['pos'];
                            $aResult['question']            = $aItems['question'];
                            $aResult['answer']              = $sAnswer;
                            $aResult['status_on_pageload']  = $aItems['status_on_pageload']; 
                            $aResult['modified_when']       = $aItems['modified_when'];
                        }
                    }          
               
//                    echo "<pre>";
//                    print_r($aResult);
//                    echo "</pre>";

                // return the complete result structure
                    return $aResult;
                }
        // end of function_exists('_readItemDetails')        
 

        ################################################################################
        // backend overview - detailed view of a single template(readTemplateDetailArray)
        ###############################################################################
                protected function _readTemplateDetailArray($iSectionId, $iTemplateId){ 
                    global $admin,$sAddonName,$sAddonThemeUrl;
                    $aResult = []; 
                    $sql = 'SELECT * FROM `'.$this->_oDb->TablePrefix.'mod_accordion_templates` '
                         . 'WHERE  `section_id` = '.$iSectionId.' '
                         . 'AND `template_id` = '.$iTemplateId.' '
                         . 'AND `active` = 1 '   ;

                    if (($oItem = $this->_oDb->query($sql))) {
                            while($aItem = $oItem->fetchAssoc()) {

                                // items from current group
                                $aResult['template_id']    = $aItem['template_id'];
                                $aResult['template_idkey'] = $admin->getIDKEY($aItem['template_id']);
                                $aResult['template_name']  = $aItem['template_name'];
                                $aResult['template_desc']  = $aItem['template_desc'];
                                $aResult['template_code']  = $aItem['template_code'];
                                $aResult['position']       = $aItem['position'];
                                $aResult['active']         = $aItem['active'];
                            }
                        }
//                        echo "<pre>";
//                        print_r($aResult);
//                        echo "</pre>";
                    // return the complete result structure
                    return $aResult;
                }
        // end of function_exists('readTemplateDetailArray')

                
                
        ###############################################################################
        // backend overview - complete List of all Templates (_readAllTemplatesArray)
        ###############################################################################
                protected function _readAllTemplatesArray($iSectionId){ 
                    global $admin;
                    // create an empty result
                    $aResult = [];    
                    // build the SQL-Statement to select from booth relating tables
                    $sql = 'SELECT * FROM `'.$this->_oDb->TablePrefix.'mod_accordion_templates` '
                                         . 'WHERE  `section_id` = '.(int)$iSectionId.' '
                                         . 'ORDER by `position`';
                    if (($oTemplates = $this->_oDb->query($sql))) {
                                while($aTemplates = $oTemplates->fetchAssoc()) {
                                $aTemplate = array();
                                // items from current group
                                $aTemplate['template_id']        = $aTemplates['template_id'];
                                $aTemplate['template_idkey']     = $admin->getIDKEY($aTemplates['template_id']);
                                $aTemplate['template_desc']      = $aTemplates['template_desc'];
                                $aTemplate['template_name']      = $aTemplates['template_name'];
                                $aTemplate['position']           = $aTemplates['position'];
                                $aTemplate['active']             = $aTemplates['active'];
                                $aTemplate['template_section']   = $aTemplates['section_id'];
                                $aResult[] = $aTemplate;
                                }
                            }
//                        echo "<pre>";
//                        print_r($aResult);
//                        echo "</pre>";
                    // return the complete result structure
                        return $aResult;
                    }
        // end of function_exists('_readAllTemplatesArray')
        //
        //
        ################################################################################
        // get Frontend-template for this section (_readFeTemplateID)
        ###############################################################################
                protected function _readFeTemplateID($iSectionId)
                {
                    $sql= 'SELECT `s_value` FROM `'.$this->_oDb->TablePrefix.'mod_accordion_settings` '
                        . 'WHERE `section_id` = '.$iSectionId.' '
                        . 'AND `s_name` = \'output_template\' '    ;
                    $sFeTemplate = $this->_oDb->get_one($sql);
                    return (@$this->_oDb->get_error()?:$sFeTemplate);
                }
         // end of function_exists('_readFeTemplateID')
         //            
        ################################################################################
        // get Frontend-template-code for this section (_readFrontendTemplate)
        ###############################################################################
                protected function  _readFrontendTemplate($iSectionId, $iTemplateId){
                    $sql = 'SELECT `template_code` FROM `'.$this->_oDb->TablePrefix.'mod_accordion_templates` '
                         . 'WHERE  `section_id` = '.$iSectionId.' '
                         . 'AND `template_id` = '.$iTemplateId.' '
                         . 'AND `active` = 1';
        //            echo $sql;
                    $sTemplateCode = $this->_oDb->get_one($sql);
                    return (@$this->_oDb->get_error()?:$sTemplateCode);
                }
         // end of function_exists('_readFrontendTemplate')

        ##################################################################################
        // frontend overview - complete List of all Entries (_readAllFEItemsArray)
        ###############################################################################
                protected function _readAllFEItemsArray($iSectionId,$iItemOrder){ 
                    global $admin;
                    $aResult = [];
                    $aSubItem = $aCurrItem = null;
                    if($iItemOrder == 1){ 
                        $sSortOrder = '`pos` ASC';
                    }elseif($iItemOrder == 2){ 
                        $sSortOrder = '`pos` DESC';
                    }elseif($iItemOrder == 3){ 
                        $sSortOrder = '`question` ASC';
                    }elseif($iItemOrder == 4){ 
                        $sSortOrder = '`question` DESC';
                    }elseif($iItemOrder == 5){ 
                        $sSortOrder = '`modified_when` ASC';
                    }elseif($iItemOrder == 6){ 
                        $sSortOrder = '`modified_when` DESC';
                    }else{ 
                        $sSortOrder = '`pos` ASC';
                    }
                    
                    $sql = 'SELECT * FROM `'.$this->_oDb->TablePrefix.'mod_accordion_questions` '
                                        .  'WHERE `section_id` = '.(int)$iSectionId.' '
                                        .  'AND `active` = 1 '
                                        .  'ORDER by '.$sSortOrder.' ';
//                    echo "<br>Haupt:".$sql;
                    if (($oItems = $this->_oDb->query($sql))) {
                        $iLastItemId = 0;
                        while ($aItems = $oItems->fetchAssoc()) {
                                $sAnswer = OutputFilterApi('ReplaceSysvar', $aItems['answer']);
//                                $sAnswer = \htmlspecialchars($sAnswer);
                                // now create a new group
                                $aCurrItem = array();
                                $aCurrItem['section_id']          = $aItems['section_id'];
                                $aCurrItem['page_id']             = $aItems['page_id'];
                                $aCurrItem['question_id']         = $aItems['question_id'];
                                $aCurrItem['image_section']       = $aItems['section_id'];
                                $aCurrItem['question_idkey']      = $admin->getIDKEY($aItems['question_id']);
                                $aCurrItem['active']              = $aItems['active'];
                                $aCurrItem['pos']                 = $aItems['pos'];
                                $aCurrItem['question']            = $aItems['question'];
                                $aCurrItem['answer']              = $sAnswer;
                                $aCurrItem['status_on_pageload']  = $aItems['status_on_pageload'];
                                $aCurrItem['modified_when']       = $aItems['modified_when'];
                                $aCurrItem['modified_by']         = $aItems['modified_by'];
                                $aResult[] = $aCurrItem;;
                            }
                        }
                        
//                    echo "<pre>";
//                    print_r($aResult);
//                    echo "</pre>";

                // return the complete result structure
                    return $aResult;    
                    }
                    

                
        // end of function_exists('_readAllFEItemsArray')
         
   
}// end of class Accordion
