<?php
/**
 * @category     Addons
 * @package      page module: accordion
 * @copyright    Uwe Jacobsen <webdesign@jacobi22.com>, Nibz, hgs, dbs
 * @author       Uwe Jacobsen <webdesign@jacobi22.com>, Nibz, hgs, dbs
 * @license      http://www.gnu.org/licenses/gpl.html   GPL License
 * @version      2.7.2
 * @lastmodified $Date: 2023/11/28
 * @since        File available since 2023/05/15
 * @description  addon accordion
 *
 * ModifyTemplate.inc.php
/* -------------------------------------------------------- */

use addon\accordion\Lib\Accordion;
use bin\{WbAdaptor, SecureTokens};
use bin\helpers\{PreCheck};

use Twig\Loader\FilesystemLoader;
use Twig\Environment;
use Twig\TwigFilter;


/* -------------------------------------------------------- */
// Must include code to stop this file being accessed directly
if (!\defined('SYSTEM_RUN')) {\header($_SERVER['SERVER_PROTOCOL'].' 404 Not Found'); echo '404 Not Found'; \flush(); exit;}
/* -------------------------------------------------------- */

$iActualSectionID = $oRequest->getParam('section_id');
if ($iActualSectionID == $section_id){
    
//load some initial datas
        if (is_readable($sAddonPath.'/init.php'))     {require ($sAddonPath.'/init.php');}
    
    $oTrans->enableAddon('modules\\\\'.$sAddonName);
    // back to the module overview
    $sec_anchor = (defined( 'SEC_ANCHOR' ) && ( SEC_ANCHOR != '' )  ? '#'.SEC_ANCHOR.$section_id : '' );
    $sAddonBackUrl = ADMIN_URL.'/pages/modify.php?page_id='.(int)$page_id.$sec_anchor;
    
    
    if (!function_exists('loader_help')){require(WB_PATH.'/include/editarea/wb_wrapper_edit_area.php');}
    
    // secure check - correct FTAN?
    if (!\bin\SecureTokens::checkFTAN ()) {
        $aMessage = \sprintf("%s\n","ModifyTemplate - Missing FTAN ".$MESSAGE['GENERIC_SECURITY_ACCESS']);
        $admin->print_error($aMessage, $sAddonBackUrl );
    }
    
    $iTemplateId = $admin->checkIDKEY('template_id', false,'POST');
    if($iTemplateId === false ) {
        $aMessage = \sprintf("%s\n","ModifyTemplate - Missing IDKey ".$MESSAGE['GENERIC_SECURITY_ACCESS']);
        $admin->print_error($aMessage, $sAddonBackUrl );
    }
//echo "Template-ID ist: ".$iTemplateId."<br>";
    $aFtan = SecureTokens::getFTAN();
    
    // complete array with replacements
    $aTplDefaults = array(
            'WB_URL' => WB_URL,
            'WB_PATH' => WB_PATH,
            'MODULE_THEME_URL'     => $sAddonThemeUrl,
            'MODULE_THEME_PATH'    => $sAddonThemePath,
            'ICON_URL'             => $sAddonThemeUrl.'/images',
            'ADDON_NAME'           => strtolower($sAddonName),
            'ADDONNAME'            => strtoupper($sAddonName),
            'ADDONURL'             => $sAddonUrl,
            'LANGUAGE'             => LANGUAGE,
            'PAGE_ID'              => $page_id,
            'SECTION_ID'           => $section_id,
            'FTAN_NAME'            => $aFtan['name'],
            'FTAN_VALUE'           => $aFtan['value'],
            'LANGUAGE'             => LANGUAGE,
            'ICON_URL'             => $sAddonThemeUrl.'/images',
            'THEME_URL'            => $sAddonThemeUrl,
            'MODIFY_URL'           => ADMIN_URL.'/pages/modify.php?page_id='.(int)$page_id,
            'SAVE_URL'             => ADMIN_URL.'/pages/save.php',
            'CANCEL_URL'           => ADMIN_URL.'/pages/modify.php?page_id='.(int)$page_id,
            'RETURN_URL'           => $sAddonBackUrl,
            'EDITTEMPLATE'         => $admin->getIDKEY('EditTempl'),
        );

    $aTwigdata = $aTplDefaults;
$oBEFunctions                                   = new Accordion();
//settings
$aTwigdata['setting']                           = $oBEFunctions->getAccordionSettings($section_id);
$aTwigdata['templates']                         = $oBEFunctions->getTemplateDetailArray($section_id,$iTemplateId);
$aTwigdata['lang']                              = $oTrans->getLangArray();
    
            if (is_readable($sAddonThemePath.'/ModifyTemplate.twig'))
        {
            // create twig template object
            $loader = new \Twig\Loader\FilesystemLoader($sAddonThemePath);
            $oTwig  = new \Twig\Environment($loader, [
                'autoescape'       => false,
                'cache'            => false,
                'strict_variables' => false,
                'debug'            => false,
                'auto_reload'      => true,
            ]);
        $oTwig->addFilter(new TwigFilter('var_dump','var_dump'));
        echo $oTwig->render('ModifyTemplate.twig', $aTwigdata);
    }
}else{
    echo $oTrans->ACCTEXT_INACTIVE_SECTION."<br>";
    
} 
// end of file